# Sample Azure Functions based on Onefuzz SDK

This uses a user-provided managed identity to interact with Onefuzz

In the Azure Functions application settings, provide the following:

* `ONEFUZZ_CLIENT_ID`
* `ONEFUZZ_CLIENT_SECRET`
* `ONEFUZZ_ENDPOINT`
* `ONEFUZZ_AUTHORITY` (optional)
